@@ -72,7 +72,6 @@ pub struct TypeAttributeBuilder {
 }
 
 impl TypeAttributeBuilder {
-    #[allow(clippy::cognitive_complexity)]
     pub fn from_debug_meta(&self, meta: &Meta) -> TypeAttribute {
         let mut flag = false;
         let mut name = self.name.clone();
@@ -521,7 +520,7 @@ impl TypeAttributeBuilder {
                                                 panic::reuse_a_trait(t);
                                             }
 
-                                            result = Some(self.from_debug_meta(&meta));
+                                            result = Some(self.from_debug_meta(meta));
                                         }
                                     }
                                     _ => panic::educe_format_incorrect(),
